
# Changelog
All notable changes to rattail-corepos will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [0.1.3] - 2020-09-19
### Changed
- Add some common email profiles, for importer diff warnings.

## [0.1.2] - 2020-09-16
### Changed
- Fix manifest to include alembic migrations.

## [0.1.1] - 2020-09-16
### Changed
- A ton of updates, mostly a "save point" release.

## [0.1.0] - 2020-02-27
### Added
- Initial version of the package; defines some basic importer/datasync logic.
